pub struct RegimentAttributes(/* private fields */);Implementations
Sourceimpl RegimentAttributes
impl RegimentAttributes
pub const NONE: Self
Sourcepub const NEVER_ROUTS: Self
pub const NEVER_ROUTS: Self
The regiment never retreats from a fight and the retreat button is disabled.
pub const UNKNOWN_FLAG_2: Self
Sourcepub const CAUSES_FEAR: Self
pub const CAUSES_FEAR: Self
Fear increases the chance that the enemy retreats during combat.
Sourcepub const CAUSES_TERROR: Self
pub const CAUSES_TERROR: Self
Stronger version of CAUSES_FEAR.
Sourcepub const GOBLIN_RACE: Self
pub const GOBLIN_RACE: Self
Used by goblins (unknown use).
pub const HATES_GREENSKINS: Self
Sourcepub const NOT_SLOWED_BY_DIFFICULT_TERRAIN: Self
pub const NOT_SLOWED_BY_DIFFICULT_TERRAIN: Self
Regiment has the same movement speed on every terrain.
Sourcepub const IMMUNE_TO_FEAR_CAN_BE_ROUTED: Self
pub const IMMUNE_TO_FEAR_CAN_BE_ROUTED: Self
Immune against any fear but can still rout.
Sourcepub const REGENERATES_WOUNDS: Self
pub const REGENERATES_WOUNDS: Self
Slowly heals damage.
Sourcepub const NEVER_RALLIES_OR_REGROUPS: Self
pub const NEVER_RALLIES_OR_REGROUPS: Self
Regiment never regroups when it is retreating.
Sourcepub const ALWAYS_PURSUES: Self
pub const ALWAYS_PURSUES: Self
Permanently follows retreating units.
Sourcepub const ENGINE_OF_WAR_RULE: Self
pub const ENGINE_OF_WAR_RULE: Self
Steam Tank flag. Can’t enter close combat anymore.
Sourcepub const INDESTRUCTIBLE: Self
pub const INDESTRUCTIBLE: Self
Regiment becomes invulnerable.
pub const UNKNOWN_FLAG_15: Self
Sourcepub const SUFFERS_ADDITIONAL_WOUNDS: Self
pub const SUFFERS_ADDITIONAL_WOUNDS: Self
Regiment gets lots of additional damage in close combat (used by skeletons).
Sourcepub const INFLICTING_CASUALTY_CAUSES_FEAR: Self
pub const INFLICTING_CASUALTY_CAUSES_FEAR: Self
If the regiment attacks an enemy using close or ranged combat, the enemy receives additional fear.
Sourcepub const DESTROYED_IF_ROUTED: Self
pub const DESTROYED_IF_ROUTED: Self
Regiment dies during retreat.
Sourcepub const THREE_SIXTY_DEGREE_VISION: Self
pub const THREE_SIXTY_DEGREE_VISION: Self
Regiment can see everything that isn’t blocked by mountains or other obstacles.
Sourcepub const SPAWNS_FANATICS: Self
pub const SPAWNS_FANATICS: Self
Regiment spawns fanatics if an enemy is near enough.
Sourcepub const WRAITH_RACE: Self
pub const WRAITH_RACE: Self
Used by wraiths (unknown use).
Sourcepub const GOBLIN_FLAG_TRADING_POST_MAP_ONLY: Self
pub const GOBLIN_FLAG_TRADING_POST_MAP_ONLY: Self
The goblins on the Trading Post map have this flag set (unknown use).
Sourcepub const IMPERVIOUS_TO_MAGIC: Self
pub const IMPERVIOUS_TO_MAGIC: Self
Regiment is completely immune against magic attacks.
Sourcepub const NEVER_RETREATS: Self
pub const NEVER_RETREATS: Self
Same as NEVER_ROUTS but the retreat button is enabled (and ignored).
Sourcepub const NO_MAGIC_ITEM_SLOTS: Self
pub const NO_MAGIC_ITEM_SLOTS: Self
Regiment has no magic item slots. Magic items can still be assigned.
Sourcepub const FANATICS_FLAG: Self
pub const FANATICS_FLAG: Self
Fanatics have this flag.
Sourcepub const FEARS_ELVES: Self
pub const FEARS_ELVES: Self
Penalty when fighting elves.
Sourceimpl RegimentAttributes
impl RegimentAttributes
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl RegimentAttributes
impl RegimentAttributes
Sourcepub const fn iter(&self) -> Iter<RegimentAttributes>
pub const fn iter(&self) -> Iter<RegimentAttributes>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RegimentAttributes>
pub const fn iter_names(&self) -> IterNames<RegimentAttributes>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.